clear
%% Load the dice data
dice = importdata('dicedata.csv');

%% Plot the outcomes of the experiments with each dice
figure(1); clf();
for d = 1:3
   subplot(3,1,d);
   bar(dice(d,:));
   axis('tight');
   title(['Dice ', num2str(d)]);
   xlabel('Face');
   ylabel('Count');

end

%% Estimate the probability of each face (normalizing)
rowsum = sum(dice,2);
dice = dice ./ repmat(rowsum, 1,6);

%% Plot the dice probabilities
figure(2); clf();
for d = 1:3
   subplot(3,1,d);
   bar(dice(d,:));
   axis('tight');
   title(['Dice ', num2str(d)]);
   xlabel('Face');
   ylabel('Probability');
end

%% Setup:
% suppose I have a cup with all 3 die in it and I randomly select a dice
% and roll that dice several (hundred) times.  Can we figure out which dice
% I selected.

%% Load the outcome of some experiemts
% Here I randomly selected a dice and rolled it many times
rolls = importdata('rolls.csv');

% Lets look at the rolls
figure(3); clf();
hist(rolls,1:6);
title(['Rolls n = ', num2str(length(rolls))]);
xlabel('Face');
ylabel('Count');

%% Prior
prior = [1/3; 1/3; 1/3];

%% For several different observations sets
obs = [1, 3, 5, 10, 100];

figure(4); clf();
plotid = 1;
for i = 1:length(obs)
    % get a subset of the data
    subrolls = rolls( 1:obs(i) );
    
    % plot the subset
    subplot(length(obs),2, plotid);
    plotid = plotid + 1;
    hist(subrolls, 1:6);
    title(['Observations n=', num2str(obs(i))]);
    xlabel('Face');
    ylabel('Count');
    
    % compute the posterior
    posterior = zeros(3,1);
    for d = 1:3
        posterior(d) = likelihood(subrolls, dice(d,:)) * prior(d); 
    end
    
    % finish bayes rule
    posterior  = posterior / sum(posterior);
    
    % Plot the posterior
    subplot(length(obs), 2, plotid);
    plotid = plotid + 1;
    bar(posterior)
    title('Posterior');
    xlabel('Face');
    ylabel('probability');
    
end













